@@ -75,12 +75,10 @@ class AaSrpManager:
 
         if esi_killmail:
             ship_type = esi_killmail["victim"]["ship_type_id"]
-            logger.debug("Ship type for kill ID %s is %s" % (kill_id, ship_type))
+            logger.debug(f"Ship type for kill ID {kill_id} is {ship_type}")
             ship_value = result["zkb"]["totalValue"]
 
-            logger.debug(
-                "Total loss value for kill id %s is %s" % (kill_id, ship_value)
-            )
+            logger.debug(f"Total loss value for kill id {kill_id} is {ship_value}")
 
             victim_id = esi_killmail["victim"]["character_id"]
 
